@@ -191,3 +191,33 @@ def getToBe(condition, singular=True, tense=PRESENT, negative=False) :
         return 'to be'
     else :
         return c.BLANK
+
+def getOnlyLetters(value):
+    return join([
+        char for char in join(
+            str(value).replace(c.UNDERSCORE, c.SPACE).replace(c.DASH, c.SPACE).split(),
+            character=c.SPACE
+        ) if char in c.CHARACTERES
+    ])
+
+def isUp(value):
+    return 1 == len(str(value)) and str(value) in c.UPPER_CASE_CHARACTERES
+
+def fromPascalToTitle(value):
+    return join([f'{c.SPACE}{char}' if isUp(char) else char for char in str(value)], character=c.BLANK)
+
+def toTitle(value):
+    return join(fromPascalToTitle(getOnlyLetters(value)).title().split(), character=c.SPACE)
+
+def toPascalCase(value):
+    return join(toTitle(value).split())
+
+def toCamelCase(value):
+    content = toPascalCase(value)
+    return join([content[:1].lower(), content[1:]])
+
+def toSnakeCase(value):
+    return join(toTitle(value).lower().split(), character=c.UNDERSCORE)
+
+def toKebabCase(value):
+    return join(toTitle(value).lower().split(), character=c.DASH)
